@@ -90,6 +90,9 @@ namespace dlib
             _at_start(true)
         {}
 
+        array(const array&) = delete;
+        array& operator=(array&) = delete; 
+
         array(
             array&& item
         ) : array()
@@ -106,7 +109,7 @@ namespace dlib
         }
 
         explicit array (
-            unsigned long new_size
+            size_t new_size
         ) :
             array_size(0),
             max_array_size(0),
@@ -125,22 +128,22 @@ namespace dlib
         );
 
         inline const T& operator[] (
-            unsigned long pos
+            size_t pos
         ) const;
 
         inline T& operator[] (
-            unsigned long pos
+            size_t pos
         );
 
         void set_size (
-            unsigned long size
+            size_t size
         );
 
-        inline unsigned long max_size(
+        inline size_t max_size(
         ) const;
 
         void set_max_size(
-            unsigned long max
+            size_t max
         );
 
         void swap (
@@ -148,7 +151,7 @@ namespace dlib
         );
 
         // functions from the enumerable interface
-        inline unsigned long size (
+        inline size_t size (
         ) const;
 
         inline bool at_start (
@@ -173,7 +176,7 @@ namespace dlib
         );
 
         void resize (
-            unsigned long new_size
+            size_t new_size
         );
 
         const T& back (
@@ -209,18 +212,14 @@ namespace dlib
         typename mem_manager::template rebind<T>::other pool;
 
         // data members
-        unsigned long array_size;
-        unsigned long max_array_size;
+        size_t array_size;
+        size_t max_array_size;
         T* array_elements;
 
         mutable T* pos;
         T* last_pos;
         mutable bool _at_start;
 
-        // restricted functions
-        array(array<T>&);        // copy constructor
-        array<T>& operator=(array<T>&);    // assignment operator        
-
     };
 
     template <
@@ -248,7 +247,7 @@ namespace dlib
             serialize(item.max_size(),out);
             serialize(item.size(),out);
 
-            for (unsigned long i = 0; i < item.size(); ++i)
+            for (size_t i = 0; i < item.size(); ++i)
                 serialize(item[i],out);
         }
         catch (serialization_error e)
@@ -268,12 +267,12 @@ namespace dlib
     {
         try
         {
-            unsigned long max_size, size;
+            size_t max_size, size;
             deserialize(max_size,in);
             deserialize(size,in);
             item.set_max_size(max_size);
             item.set_size(size);
-            for (unsigned long i = 0; i < size; ++i)
+            for (size_t i = 0; i < size; ++i)
                 deserialize(item[i],in);
         }
         catch (serialization_error e)
@@ -333,7 +332,7 @@ namespace dlib
         >
     const T& array<T,mem_manager>::
     operator[] (
-        unsigned long pos
+        size_t pos
     ) const
     {
         // make sure requires clause is not broken
@@ -356,7 +355,7 @@ namespace dlib
         >
     T& array<T,mem_manager>::
     operator[] (
-        unsigned long pos
+        size_t pos
     ) 
     {
         // make sure requires clause is not broken
@@ -379,7 +378,7 @@ namespace dlib
         >
     void array<T,mem_manager>::
     set_size (
-        unsigned long size
+        size_t size
     )
     {
         // make sure requires clause is not broken
@@ -405,7 +404,7 @@ namespace dlib
         typename T,
         typename mem_manager
         >
-    unsigned long array<T,mem_manager>::
+    size_t array<T,mem_manager>::
     size (
     ) const
     {
@@ -420,7 +419,7 @@ namespace dlib
         >
     void array<T,mem_manager>::
     set_max_size(
-        unsigned long max
+        size_t max
     )
     {
         reset();
@@ -458,7 +457,7 @@ namespace dlib
         typename T,
         typename mem_manager
         >
-    unsigned long array<T,mem_manager>::
+    size_t array<T,mem_manager>::
     max_size (
     ) const
     {
@@ -476,8 +475,8 @@ namespace dlib
         array<T,mem_manager>& item
     )
     {
-        unsigned long    array_size_temp        = item.array_size;
-        unsigned long    max_array_size_temp    = item.max_array_size;
+        auto             array_size_temp        = item.array_size;
+        auto             max_array_size_temp    = item.max_array_size;
         T*               array_elements_temp    = item.array_elements;
 
         item.array_size         = array_size;
@@ -646,7 +645,7 @@ namespace dlib
         >
     void array<T,mem_manager>::
     resize (
-        unsigned long new_size
+        size_t new_size
     )
     {
         if (this->max_size() < new_size)
@@ -654,7 +653,7 @@ namespace dlib
             array temp;
             temp.set_max_size(new_size);
             temp.set_size(new_size);
-            for (unsigned long i = 0; i < this->size(); ++i)
+            for (size_t i = 0; i < this->size(); ++i)
             {
                 exchange((*this)[i],temp[i]);
             }
@@ -769,7 +768,7 @@ namespace dlib
             array temp;
             temp.set_max_size(this->size()*2 + 1);
             temp.set_size(this->size()+1);
-            for (unsigned long i = 0; i < this->size(); ++i)
+            for (size_t i = 0; i < this->size(); ++i)
             {
                 exchange((*this)[i],temp[i]);
             }
